#!/bin/bash

# author : Son|c (emmanuel.bailleul@cegetel.net)
# Inpired by Slackware's slackbuild
# Source : http://www.stunnel.org/download/stunnel/src/stunnel-4.27.tar.gz

# program name/version
softversion='4.27'
softname='stunnel'

# architecture/package version
arch='i486'
cpu='i686'
packageversion='64.1'

# number of parallel tasks of make
ntasks='-j2'

# parameters needed for the build process
buildir=$(pwd)
package="$softname-$softversion-$arch-$packageversion"

# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
rm -f $package.*
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/src/$softname-$softversion

# make a slack-desc file
cat <<EOF > $dest/install/slack-desc
       |-----handy-ruler------------------------------------------------------|
stunnel: stunnel (Universal SSL tunnel)
stunnel:
stunnel: The stunnel program is designed to work as an SSL encryption wrapper
stunnel: between remote client and local (inetd-startable) or remote servers.
stunnel: The goal is to facilitate SSL encryption and authentication for
stunnel: non-SSL-aware programs.
stunnel:
stunnel: stunnel can be used to add SSL functionality to commonly used inetd
stunnel: daemons like POP-2, POP-3 and IMAP servers without any changes in the
stunnel: programs' code.
stunnel:
EOF

# extract sources
srcdir="$softname-$softversion"
cd $buildir
rm -rf $srcdir
tar xzvf $srcdir.tar.gz

# Patch source to add "xforwardedfor" feature :
mv $srcdir $srcdir.orig
patch -p0 < stunnel-4.27-xforwardedfor.patch
mv $srcdir.orig $srcdir

cd $srcdir

# set correct permissions
chown -R root.root . 
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;

export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

./configure \
  --prefix= \
  --libdir=/usr/lib \
  --exec-prefix= \
  --sysconfdir=/etc \
  --datadir=/usr/share \
  --mandir=/usr/man \
  --sbindir=/usr/sbin \
  --localstatedir=/var

make $ntasks || make || exit 1

mkdir -p $dest/var/run/stunnel
# This will produce a useless key.
make -i install DESTDIR=$dest
# Get rid of key, so nobody tries to use it:
rm -f $dest/etc/stunnel/stunnel.pem

# Add cnf:
cat tools/stunnel.cnf > $dest/etc/stunnel/stunnel.cnf.new

# Add a script to generate a new key
echo "#!/bin/sh
USE_DH=0

openssl req -new -x509 -days 365 -nodes \\
  -config ./stunnel.cnf -out stunnel.pem -keyout stunnel.pem

test \$USE_DH -eq 0 || openssl gendh 512 >> stunnel.pem

openssl x509 -subject -dates -fingerprint -noout \\
  -in stunnel.pem

chmod 600 stunnel.pem
rm -f stunnel.rnd" > $dest/etc/stunnel/generate-stunnel-key.sh
chmod 755 $dest/etc/stunnel/generate-stunnel-key.sh

mkdir -p $dest/usr/doc/stunnel-$softversion
mv $dest/usr/share/doc/stunnel/* $dest/usr/doc/stunnel-$softversion
rm -rf $dest/usr/share

mkdir -p $dest/usr/man/pl/man8
mv $dest/usr/man/man8/stunnel.pl.8 $dest/usr/man/pl/man8/stunnel.8
mkdir -p $dest/usr/man/fr/man8
mv $dest/usr/man/man8/stunnel.fr.8 $dest/usr/man/fr/man8/stunnel.8
gzip -9 $dest/usr/man/*/man?/*.? $dest/usr/man/man?/*.?

find $dest | xargs file | grep -e "executable" -e "shared object" \
  | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

# The 4.15 version of stunnel caused some bizarre perms, so
# we'll protect against that:
chmod 0755 $dest/var/lib
chown root:root $dest/var/lib

# Create doinst
echo "config() {
  NEW=\"\$1.new\"
  OLD=\"\$1\"
  # If there's no config file by that name, mv it over:
  if [ ! -r \$OLD ]; then
    mv \$NEW \$OLD
  elif [ \"\`cat \$OLD | md5sum\`\" = \"\`cat \$NEW | md5sum\`\" ]; then # toss the redundant copy
    rm \$NEW
  fi
  # Otherwise, we leave the .new copy for netpkg to consider...
}
config etc/stunnel/stunnel.cnf" > $dest/install/doinst.sh
chmod 755 $dest/install/doinst.sh

cd $buildir
cp build-stunnel.sh $dest/usr/src/stunnel-$softversion/

#------------------( Create The *.dep File )
cd $dest
depfinder $dest > $buildir/$package.dep

# Build the package:
/sbin/makepkg -l y -c n $dest.txz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.txz > $package.md5

# Create source file
echo "http://www.stunnel.org/download/stunnel/src/stunnel-4.27.tar.gz" > $package.src
echo "http://download.zenwalk.org/people/emmanuel/$softname-$softversion/build-$softname.sh" >> $package.src
echo "http://download.zenwalk.org/people/emmanuel/$softname-$softversion/stunnel-4.27-xforwardedfor.patch" >> $package.src
